#!/bin/sh

PATH="/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin"

dir="/var/tmp/upgrade"
if [ ! -e $dir ]; then
	mkdir -p $dir
fi

if [ ! -e /dev/mmcblk0p3 ]; then
	exit 1
fi

mount /dev/mmcblk0p3 $dir
if [ $? -ne 0 ]; then
	umount $dir
	exit 1
fi

filename=$1
if [ -z "$filename" ] || [ ! -e "$dir/$filename" ]; then
	umount $dir
	logger "no firmware file"
	exit 1
fi

# extract file
tar -xf $dir/$filename -C $dir &> /dev/null

# file check
if [ ! -e "$dir/file_list" ]; then
	logger "no firmware file list"
	exit 1
fi
. $dir/file_list

rm -f $dir/$filename

# key file
pub_key="/etc/update-pkg/key/public-key.pem"

# pre setup (option)
if [ -n "$pre_setup_file" ] && [ -n "$pre_setup_sign" ]; then
	pre_setup_sign="$dir/$pre_setup_sign"
	pre_setup_file="$dir/$pre_setup_file"

	openssl dgst -sha256 -verify $pub_key -signature $pre_setup_sign $pre_setup_file &> /dev/null
	if [ $? -ne 0 ]; then
		rm -f  $pre_setup_file $pre_setup_sign
		umount $dir
		logger "pre_setup signature is bad."
		exit 1
	fi

	tar -xf "$pre_setup_file" -C /var/tmp &> /dev/null
	if [ -e /var/tmp/pre_setup.sh ]; then
		/var/tmp/pre_setup.sh
		rm /var/tmp/pre_setup.sh
	fi
fi

# verify file
if [ -n "$fw_file" ] && [ -n "$fw_sign" ]; then
	fw_sign="$dir/$fw_sign"
	fw_file="$dir/$fw_file"

	openssl dgst -sha256 -verify $pub_key -signature $fw_sign $fw_file &> /dev/null
	if [ $? -ne 0 ]; then
		rm -f  $fw_sign $fw_file $initram_sign $initram_file
		umount $dir
		logger "firmware signature is bad."
		exit 1
	fi
fi

if [ -n "$initram_file" ] && [ -n "$initram_sign" ]; then
	initram_sign="$dir/$initram_sign"
	initram_file="$dir/$initram_file"

	openssl dgst -sha256 -verify $pub_key -signature $initram_sign $initram_file &> /dev/null
	if [ $? -ne 0 ]; then
		rm -f  $fw_sign $fw_file $initram_sign $initram_file
		umount $dir
		logger "initramfs signature is bad."
		exit 1
	fi
fi

# keep current config
/etc/update-pkg/convert_cfg.sh /etc/setup-netcfg/user.cfg > $dir/scr.json

# reset lte module
/usr/local/bin/at_cmd_cli AT+UFACTORY=0,1 &> /dev/null

# opvn files
tar cvf $dir/ovpn.tar /etc/openvpn &> /dev/null

# make working rootfs on ram
if [ -n "$initram_file" ] && [ -n "$initram_sign" ]; then
	fw_root="/tmp/fw_root"
	if [ ! -e $fw_root ]; then
		mkdir -p $fw_root
	fi
	cd $fw_root

	gzip -d -c $initram_file | cpio -i &> /dev/null
	cp /etc/update-pkg/fw_chroot.sh $fw_root
	cp $dir/file_list $fw_root/
fi

umount $dir

exit 0
