#!/bin/sh

PATH="/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin"

loop_cnt=0
while [ -e /var/tmp/.discover_running ]; do
	if [ $loop_cnt -eq 10 ]; then
		exit 1
	fi
	sleep 1
	loop_cnt=`expr $loop_cnt + 1`
done
touch /var/tmp/.discover_running


prog_name="/usr/sbin/tcpdump"
config_file=/etc/setup-netcfg/user.cfg
wsd_in="/etc/cam-wsd.txt"
tmp_wsd="/tmp/wsd"
temp1="/tmp/temp1"
temp2="/tmp/temp2"
temp3="/tmp/temp3"
temp4="/tmp/temp4"
temp5="/tmp/temp5"
temp_dump="/tmp/temp_dump"
temp_ping="/tmp/temp_ping"
temp_discover="/tmp/temp_discover"

# load config-fie
. $config_file

iface=$1
upnp_in=$2

if [ -z "$iface" ]; then
	iface="br0"
fi

if [ -z "$upnp_in" ]; then
	upnp_in="/etc/cam-search.txt"
fi

uuid=`cat /proc/sys/kernel/random/uuid`
cat $wsd_in | sed "s/uuid:XXX/uuid:$uuid/g" > $tmp_wsd

if [ -e $temp1 ]; then
	rm $temp1
fi
if [ -e $temp_discover ]; then
	rm $temp_discover
fi
touch $temp_discover

ip -f inet addr | grep "$iface" > /dev/null
if [ $? -ne 0 ]; then
	rm -f /var/tmp/.discover_running
	exit 0
fi


# $1:camera-mac
check_regnum() {
	if [ "$1" = "$cam1_mac" ]; then
		return 1
	elif [ "$1" = "$cam2_mac" ]; then
		return 2
	elif [ "$1" = "$cam3_mac" ]; then
		return 3
	elif [ "$1" = "$cam4_mac" ]; then
		return 4
	fi

	if [ -z "$cam1_mac" ]; then
		cam1_mac=$1
		return 1
	elif [ -z "$cam2_mac" ]; then
		cam2_mac=$1
		return 2
	elif [ -z "$cam3_mac" ]; then
		cam3_mac=$1
		return 3
	elif [ -z "$cam4_mac" ]; then
		cam4_mac=$1
		return 4
	fi
	return 0
}



##### scan camera (WS-Discovery)
sudo /usr/bin/socat -T2 STDIO UDP4-DATAGRAM:239.255.255.250:3702,bindtodevice=$iface \
	< $tmp_wsd  > $temp1
if [ -e "$temp1" ]; then
	cat $temp1 | sed "s/:Envelope>/:Envelope>\n/g" | grep "<d:XAddrs>" > $temp2
	found=`cat $temp2 | wc -l`

	cam_cnt=0
	while read line; do
		echo $line | sed "s/<d:XAddrs>/<d:XAddrs>\n/g" | sed "s/<\/d:XAddrs>/<\/d:XAddrs>\n/g" | grep "</d:XAddrs>" > $temp3
		cat $temp3 | sed "s/<\/d:XAddrs>/ /g" | sed "s/ /\n/g" | grep "onvif/device_service" > $temp4
		url_cnt=`cat $temp4 | wc -l`
		if [ $url_cnt -eq 1  ]; then
			found_ip=`cat $temp4 | sed "s/http:\/\// /g" | sed "s/:/ /g" | sed "s/\// /g" | awk 'NR==1 { print $1 }'`
		else
			found_ip=`cat $temp4 | sed "s/http:\/\// /g" | sed "s/:/ /g" | sed "s/\// /g" | grep -v "169.254" | awk 'NR==1 { print $1 }'`
		fi

		if [ -z "$found_ip" ]; then
			continue
		fi
		dup=0
		for n in `seq 1 $found`; do
			chk_ip=cam_ip_$n
			if [ "$found_ip" = "${!chk_ip}" ]; then
				dup=1
			fi
		done
		if [ $dup -eq 0 ]; then
			cam_cnt=`expr $cam_cnt + 1`
			echo "cam_ip_$cam_cnt=\"$found_ip\"" >> $temp_discover
			export cam_ip_$cam_cnt=$found_ip

			echo $line | sed "s/onvif:\/\/www.onvif.org\/hardware\//\nonvif:\/\/www.onvif.org\/hardware /g" > $temp5
			hardware=`cat $temp5 | grep "hardware" | awk 'NR==1 { print $2 }'`
			echo "product_name_$cam_cnt=\"$hardware\"" >> $temp_discover
			echo $line | sed "s/onvif:\/\/www.onvif.org\/name\//\nonvif:\/\/www.onvif.org\/name /g"  > $temp5
			name=`cat $temp5 | grep "name" | sed -n 1p | awk 'NR==1 { print $2 }'`
			echo "cam_modelName_$cam_cnt=\"$name\"" >> $temp_discover

			chk_ip=cam_ip_$cam_cnt
			port_found=0
			if [ "$inet_if" != "ETH0" ]; then
				/usr/sbin/ethtool eth0 | grep "Link detected: yes" > /dev/null
				if [ $? -eq 0 ]; then
					sudo $prog_name -i eth0 -e -t -n src host ${!chk_ip} > $temp_dump 2>/dev/null &
					ping ${!chk_ip} -c 2 >/dev/null 2>&1
					temp_pid=`ps | grep "$prog_name" | grep -v "grep" | awk '{print $1}'`
					sudo /bin/kill -HUP $temp_pid
					cat $temp_dump | grep "${!chk_ip} >" > $temp_ping
					if [ $? -eq 0 ]; then
						echo "cam_if_$cam_cnt=0" >> $temp_discover
						mac=`cat $temp_ping | sed -n 1p | awk '{print $1}'`
						echo "cam_mac_$cam_cnt=\"$mac\"" >> $temp_discover
						port_found=1
					fi
				fi
			fi
			if [ "$inet_if" != "ETH1" ]; then
				if [ $port_found -eq 0 ]; then
					/usr/sbin/ethtool eth1 | grep "Link detected: yes" > /dev/null
					if [ $? -eq 0 ]; then
						sudo $prog_name -i eth1 -e -t -n src host ${!chk_ip} > $temp_dump 2>/dev/null &
						ping ${!chk_ip} -c 2 >/dev/null 2>&1
						temp_pid=`ps | grep "$prog_name" | grep -v "grep" | awk '{print $1}'`
						sudo /bin/kill -HUP $temp_pid
						cat $temp_dump | grep "${!chk_ip} >" > $temp_ping
						if [ $? -eq 0 ]; then
							echo "cam_if_$cam_cnt=1" >> $temp_discover
							mac=`cat $temp_ping | sed -n 1p | awk '{print $1}'`
							echo "cam_mac_$cam_cnt=\"$mac\"" >> $temp_discover
						fi
					fi
				fi
			fi
		fi
	done < $temp2
	rm $temp1
fi


##### get camera-id(serial number),.. (UPnP)
sudo /usr/bin/socat -T1 STDIO UDP4-DATAGRAM:239.255.255.250:1900,bindtodevice=$iface \
	< $upnp_in | grep "Location:" > $temp1
if [ ! -e "$temp1" ]; then
	rm -f /var/tmp/.discover_running
	exit 0
fi

count=1
while read line; do
	temp_url=${line#*: }
	temp_url=${temp_url%$'\r'}
	temp_ip=${temp_url#*//}
	temp_ip=${temp_ip%:*}

	curl "$temp_url" 2> /dev/null > $temp2

	found=0
	for n in `seq 1 4`; do
		chk_ip=cam_ip_$n
		if [ "$temp_ip" = "${!chk_ip}" ]; then
			found=$n
			break
		fi
	done

	if [ $found -ne 0 ]; then
		cnt=$found
	else
		cam_cnt=`expr $cam_cnt + 1`
		cnt=$cam_cnt
		echo "cam_ip_$cnt=\"$temp_ip\"" >> $temp_discover
		temp_name=`cat $temp2 | awk 'match($0, /<modelName/) {print substr($0, RSTART+RLENGTH)}' \
	                          | awk 'match($0, /<\/modelName>/) {print substr($0, 1, RSTART-1)}'`
		echo "cam_modelName_$cnt=\"$temp_name\"" >> $temp_discover

		port_found=0
		if [ "$inet_if" != "ETH0" ]; then
			/usr/sbin/ethtool eth0 | grep "Link detected: yes" > /dev/null
			if [ $? -eq 0 ]; then
				sudo $prog_name -i eth0 -e -t -n src host $temp_ip > $temp_dump 2>/dev/null &
				ping $temp_ip -c 2 >/dev/null 2>&1
				temp_pid=`ps | grep "$prog_name" | grep -v "grep" | awk '{print $1}'`
				sudo /bin/kill -HUP $temp_pid
				cat $temp_dump | grep "$temp_ip >" > $temp_ping
				if [ $? -eq 0 ]; then
					echo "cam_if_$cnt=0" >> $temp_discover
					mac=`cat $temp_ping | sed -n 1p | awk '{print $1}'`
					echo "cam_mac_$cnt=\"$mac\"" >> $temp_discover
					port_found=1
				fi
			fi
		fi
		if [ "$inet_if" != "ETH1" ]; then
			if [ $port_found -eq 0 ]; then
				/usr/sbin/ethtool eth1 | grep "Link detected: yes" > /dev/null
				if [ $? -eq 0 ]; then
					sudo $prog_name -i eth1 -e -t -n src host $temp_ip > $temp_dump 2>/dev/null &
					ping $temp_ip -c 2 >/dev/null 2>&1
					temp_pid=`ps | grep "$prog_name" | grep -v "grep" | awk '{print $1}'`
					sudo /bin/kill -HUP $temp_pid
					cat $temp_dump | grep "$temp_ip >" > $temp_ping
					if [ $? -eq 0 ]; then
						echo "cam_if_$cnt=1" >> $temp_discover
						mac=`cat $temp_ping | sed -n 1p | awk '{print $1}'`
						echo "cam_mac_$cnt=\"$mac\"" >> $temp_discover
					fi
				fi
			fi
		fi
	fi

	temp_sn=`cat $temp2 | awk 'match($0, /<serialNumber>/) {print substr($0, RSTART+RLENGTH)}' \
	                        | awk 'match($0, /<\/serialNumber>/) {print substr($0, 1, RSTART-1)}'`
	echo "cam_sn_$cnt=\"$temp_sn\"" >> $temp_discover
	temp_mnf=`cat $temp2 | awk 'match($0, /<manufacturer>/) {print substr($0, RSTART+RLENGTH)}' \
	                         | awk 'match($0, /<\/manufacturer>/) {print substr($0, 1, RSTART-1)}'`
	echo "cam_manufacturer_$cnt=\"$temp_mnf\"" >> $temp_discover

	count=`expr $count + 1`
done < $temp1


##### output cam-info
. $temp_discover

for n in `seq 1 $cam_cnt`; do
	mac=cam_mac_$n
	ip=cam_ip_$n
	pname=product_name_$n
	mName=cam_modelName_$n
	port=cam_if_$n
	sn=cam_sn_$n
	manufacturer=cam_manufacturer_$n

	if [ -z "${!mac}" ]; then
		macaddr=`sudo /usr/bin/arp-scan -l -I br0 | grep "${!ip}" | awk '{ print $2; }'`
	else
		macaddr=${!mac}
	fi

	check_regnum "$macaddr"
	num=$?
	if [ $num -ne 0 ]; then 
		echo "cam_mac_${num}=\"$macaddr\""
		tmpip=`echo ${!ip} | awk '{ print $1 }'`
		echo "cam_ip_${num}=\"$tmpip\""
		echo "product_name_${num}=\"${!pname}\""
		echo "cam_modelName_${num}=\"${!mName}\""
		echo "cam_if_${num}=\"${!port}\""
		echo "cam_sn_${num}=\"${!sn}\""
		echo "cam_manufacturer_${num}=\"${!manufacturer}\""
	fi
done



if [ -e $temp1 ]; then
	rm $temp1
fi
if [ -e $temp2 ]; then
	rm $temp2
fi
if [ -e $temp3 ]; then
	rm $temp3
fi
if [ -e $temp4 ]; then
	rm $temp4
fi
if [ -e $temp5 ]; then
	rm $temp5
fi
if [ -e $temp_dump ]; then
	rm $temp_dump
fi
if [ -e $temp_ping ]; then
	rm $temp_ping
fi
if [ -e $tmp_wsd ]; then
	rm $tmp_wsd
fi
if [ -e $temp_discover ]; then
	rm $temp_discover
fi

rm -f /var/tmp/.discover_running
exit 0


