#!/bin/sh

# config file
conf_file="/etc/setup-netcfg/user.cfg"

# load config
. $conf_file


# setup port and command
DEV="/dev/ttyACM0"
ATCMD="/usr/local/bin/at_cmd_cli"

if [ ! -e "$DEV" ]; then
	echo "ERR : LTE module is not found" 1>&2
	exit 1
fi

/bin/stty -F $DEV 115200 raw -echo
$ATCMD AT 1> /dev/null  # for auto baudrate detect


# test connection
$ATCMD AT 1> /dev/null
if [ $? -ne 0 ]; then
	echo "LTE : No response from LTE module" 1>&2
	exit 1
fi


#
# functions
#
function connect() {
	# APN Paramter check
	if [ -z "$lte_apn" ] || [ -z "$lte_user" ] || [ -z "$lte_password" ]; then
		echo "LTE : Invalid APN configuration" 1>&2
		return 1
	fi

	if [ $lte_auth = "none" ]; then
		AUTH_TYPE=0
	elif [ $lte_auth = "PAP" ]; then
		AUTH_TYPE=1
	elif [ $lte_auth = "CHAP" ]; then
		AUTH_TYPE=2
	else
		echo "LTE : un-support auth type" 1>&2
		return 1
	fi

	# connect config
	$ATCMD AT+CFUN=4   1> /dev/null
	$ATCMD AT+UCGDFLT=1,"\"IP\"",\""$lte_apn\"",,,,,,,,,,,,,,,,,,$AUTH_TYPE,"\"$lte_user\"","\"$lte_password\"" 1> /dev/null
	$ATCMD AT+CFUN=1  1> /dev/null

	# wait for active, max 22sec
	sleep 2

	for n in `seq 1 10`; do
		$ATCMD AT+CGACT? | grep "4,1"
		if [ $? -ne 0 ]; then
			echo "LTE : Waiting for PDP context activation, $n"
		else
			break
		fi
		sleep 2
	done
	if [ $n -eq 10 ]; then
		echo "LTE : PDP context is not activated, $?" 1>&2
		$ATCMD AT+CFUN=4  1> /dev/null
		return 1
	fi

	# start
	$ATCMD AT+UPSD=0,1,"\"$lte_apn\"" 1> /dev/null
	if [ $? -ne 0 ]; then
		echo "LTE : Set APN failed, $?" 1>&2
		$ATCMD AT+CFUN=4  1> /dev/null
		return 1
	fi

	sleep 1

	$ATCMD AT+UPSD=0,100,4 1> /dev/null
	if [ $? -ne 0 ]; then
		echo "LTE : Set cid failed, $?" 1>&2
		$ATCMD AT+CFUN=4  1> /dev/null
		return 1
	fi

	sleep 1

	# check connection
	$ATCMD AT+UPSDA=0,3 1> /dev/null
	if [ $? -ne 0 ]; then
		echo "LTE : Connect to APN failed, $?" 1>&2
		$ATCMD AT+CFUN=4  1> /dev/null
		return 1
	fi

	# report
	#$ATCMD AT+CGCONTRDP

	echo "LTE : Connected to APN($lte_apn)"

	return 0
}

function disconnect() {
	$ATCMD AT+CFUN=4 1> /dev/null
	return 0
}


#
#
#
case "$1" in
start)
	connect
	;;

stop)
	disconnect
	;;

*)
	echo "Usage: lte_conn {start|stop}"
	exit 1
	;;
esac


exit 0
