#!/bin/sh

# setup port and command
DEV="/dev/ttyACM0"
ATCMD="/usr/local/bin/at_cmd_cli"

if [ ! -e "$DEV" ]; then
	echo "ERR : LTE module is not found" 1>&2
	exit 1
fi


/bin/stty -F $DEV 115200 raw -echo
$ATCMD AT 1> /dev/null  # for auto baudrate detect


# test connection
$ATCMD AT 1> /dev/null
if [ $? -ne 0 ]; then
	echo "ERR : No response from LTE module" 1>&2
	exit 1
fi


#
# functions
#
function get_rssi() {
	local tmp=`$ATCMD AT+CESQ | grep 'CESQ' | awk -F, '{print $6}' | sed -e "s/[\r\n]\+//g"`

	if [ -z "$tmp" ]; then
		echo "ERR : LTE module is not working" 1>&2
		return 1
	elif [ $tmp -eq 255 ]; then
		lte_rssi=-255
	elif [ $tmp -eq 97 ]; then
		lte_rssi=-44
	else
		lte_rssi=`expr $tmp - 141`
	fi
	echo $lte_rssi
	return 0
}

function get_addr() {
	$ATCMD 'AT+CGACT?' | grep "4,1" > /dev/null
	st1=$?
	$ATCMD 'AT+CFUN?'  | grep "1,0" > /dev/null
	st2=$?
	if [ $st1 -eq 0 ] && [ $st2 -eq 0 ]; then
		tmp=`$ATCMD AT+CGCONTRDP | grep 'CGCONTRDP' | awk '{print $2;}' | cut -d, -f4 | sed -e s/\"//g`
		lte_addr=`echo $tmp | awk 'BEGIN {FS=".";OFS="."}{print $1,$2,$3,$4}'`
	else
		echo "ERR : No APN connection" 1>&2
	fi

	echo $lte_addr

	return 0
}

function get_dns() {
	if [ "$1" -eq 2 ]; then
		fld=7
	else
		fld=6
	fi

	$ATCMD 'AT+CGACT?' | grep "4,1" > /dev/null
	st1=$?
	$ATCMD 'AT+CFUN?'  | grep "1,0" > /dev/null
	st2=$?
	if [ $st1 -eq 0 ] && [ $st2 -eq 0 ]; then
		tmp=`$ATCMD AT+CGCONTRDP | grep 'CGCONTRDP' | awk '{print $2;}' | cut -d, -f$fld | sed -e s/\"//g`
		dns_addr=`echo $tmp | awk 'BEGIN {FS=".";OFS="."}{print $1,$2,$3,$4}'`
	else
		echo "ERR : No APN connection" 1>&2
		echo $dns_addr
		return 1
	fi

	echo $dns_addr

	return 0
}

function get_imei() {
	local id=`$ATCMD AT+CGSN | grep '[0-9]' | sed -e "s/[\r\n]\+//g"`

	if [ -z "$id" ]; then
		echo "ERR : LTE module is not working" 1>&2
		return 1
	else
		echo $id
	fi
	return 0
}

function get_msisdn() {
	local id=`$ATCMD AT+CNUM | grep 'CNUM'  | awk -F, '{print $2}' | sed -e "s/[\r\n]\+//g" | sed -e "s/\"//g"`

	if [ -z "$id" ]; then
		echo "ERR : LTE module is not working" 1>&2
		return 1
	else
		echo $id
	fi
	return 0
}

function get_imsi() {
	local id=`$ATCMD AT+CIMI | grep '[0-9]' | sed -e "s/[\r\n]\+//g"`

	if [ -z "$id" ]; then
		echo "ERR : LTE module is not working" 1>&2
		return 1
	else
		echo $id
	fi
	return 0
}

function get_iccid() {
	local id=`$ATCMD AT+CCID? | grep 'CCID'  | awk '{print $2}' | sed -e "s/[\r\n]\+//g"`

	if [ -z "$id" ]; then
		echo "ERR : LTE module is not working" 1>&2
		return 1
	else
		echo $id
	fi
	return 0
}


#
#
#
case "$1" in
RSSI)
	get_rssi
	;;
ADDR)
	get_addr
	;;
DNS1)
	get_dns 1
	;;
DNS2)
	get_dns 2
	;;
IMEI)
	get_imei
	;;
MSISDN)
	get_msisdn
	;;
IMSI)
	get_imsi
	;;
ICCID)
	get_iccid
	;;

*)
	echo "Usage: lte_info.sh {RSSI|ADDR|DNS1|DNS2|MSISDN|IMEI|IMSI|ICCID}" 1>&2
	exit 1
	;;
esac

exit 0
