#!/bin/sh

PATH="/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin"

# hw info
hwinfo_file=/tmp/hwinfo
. $hwinfo_file

# config file
. /etc/setup-netcfg/user.cfg

# running status
lte_cron_running="/var/tmp/.lte_cron"

if [ "$inet_if" != "LTE" ] || \
   [ -z "$lte_apn" ] || [ -z "$lte_user" ] || [ -z "$lte_password" ] || \
   [ -e "$lte_cron_running" ]; then
	exit 0
fi

#
# monitor lte network
#
lte_log_file="/var/log/lte.log"
MAX_LINE=10080  # 7days
cstatus="failed"

function lte_led_ctl() {
	if [ "$safie_cfg_enable" = "1" ]; then
		return 0
	fi

	if [ "$cstatus" = "connect" ]; then
		st_led_ctl green on
	fi
	if [ "$rssi" -le -95 ]; then
		st_led_ctl yellow on
	fi
	if [ "$cstatus" = "disconnect" ]; then
		st_led_ctl yellow blink_slow
	fi
}

function put_lte_log() {
	lcnt=`wc -l $lte_log_file | awk '{print $1}'`
	if [ "$lcnt" -ge $MAX_LINE ]; then
		sed -i -e '1d' $lte_log_file
	fi

	# rssi
	tmp=`/bin/date +"%Y-%m-%d %H:%M:%S"`
	rssi=`lte_info.sh RSSI`

	# check if ping to dns is ok
	dns_addr=`lte_info.sh DNS1`
	if [ $? -ne 0 ]; then
		dns_addr="8.8.8.8"
	fi

	ping -c 1 -w 5 $dns_addr &> /dev/null
	if [ $? -eq 0 ]; then
		cstatus="connect"
	else
		cstatus="disconnect"
	fi

	echo "[$tmp] rssi : $rssi, status : $cstatus" >> $lte_log_file
}


touch "$lte_cron_running"

lte=`/sbin/ifconfig | grep usb0 | wc -l`
if [ $lte -eq 0 ]; then
	ifdown usb0
	sleep 1
	echo "usb0 up by cron" | logger
	ifup usb0
else
	put_lte_log
fi

# st led control for V2 board
if [[ "$board_version" = "V2R"[0-9] ]]; then
	lte_led_ctl
fi

rm -f "$lte_cron_running"

exit 0
