#!/bin/sh

# $1: poe-port: 0/1 (eth0/eth1)
#		eth0 <- poe2
#		eth1 <- poe1
#
# $2: ctrl: 0/1/2  : off/on/reset(off&on)
#
hwinfo_file=/tmp/hwinfo

. $hwinfo_file


function prn_usage()
{
	echo "poe.sh eth_port action"
	echo "    eth_port : 0 (eht0) or 1 (eth1) or 2 (both ports)"
	echo "    action   : 0 (off) or 1 (on) or 2 (reset)"
}


#
# V1Rx board
#
function v1_scr_poe_off()
{
	if [ "$1" = 0 ]; then
		port="$gpio_poe2"
	elif [ "$1" = 1 ]; then
		port="$gpio_poe1"
	else
		return
	fi
	/usr/local/bin/gpio_ctl -w $port 0
}

function v1_scr_poe_on()
{
	if [ "$1" = 0 ]; then
		port="$gpio_poe2"
	elif [ "$1" = 1 ]; then
		port="$gpio_poe1"
	else
		return
	fi
	/usr/local/bin/gpio_ctl -w $port 1
}

function v1_scr_poe()
{
	port1="gpio_poe1"

	if [ "$1" = 2 ] && [ "$2" = 2 ]; then
		v1_scr_poe_off 0
		v1_scr_poe_off 1
		sleep 10
		v1_scr_poe_on 0
		v1_scr_poe_on 1
	else
		case "$2" in
		0)
			v1_scr_poe_off $1
	        ;;
		1)
			v1_scr_poe_on $1
	        ;;
		2)
			v1_scr_poe_off $1
			sleep 10
			v1_scr_poe_on $1
	        ;;
		*)
			prn_usage
	        ;;
		esac
	fi
}


#
# V2Rx board
#
#   PoE chip i2c addr 0x28
#     off 19h : bit 5:4
#     on  14h : detect/class enable bit 5:4, 1:0
#
function v2_scr_poe_off()
{
	if [ "$1" = 0 ]; then
		p_off="0x20"
	elif [ "$1" = 1 ]; then
		p_off="0x10"
	else
		return
	fi

	/usr/sbin/i2cset -y 0 0x28 0x19 "$p_off" b
}

function v2_scr_poe_on()
{
	# current dc
	dc_en=`/usr/sbin/i2cget -y 0 0x28 0x14`

	if [ "$dc_en" = "0xff" ]; then
		return
	fi
	if [ "$1" = 1 ]; then
		dc_val=0x11
	elif [ "$1" = 0 ]; then
		dc_val=0x22
	else
		return
	fi
	# new dc
	dc_set=`printf '0x%x' $((dc_en|dc_val))`
	/usr/sbin/i2cset -y 0 0x28 0x14 "$dc_set" b
}

function v2_scr_poe()
{
	if [ "$1" = 2 ] && [ "$2" = 2 ]; then
			v2_scr_poe_off 0
			v2_scr_poe_off 1
			sleep 10
			v2_scr_poe_on 0
			v2_scr_poe_on 1
	else
		case "$2" in
		0)
			v2_scr_poe_off $1
	        ;;
		1)
			v2_scr_poe_on $1
	        ;;
		2)
			v2_scr_poe_off $1
			sleep 10
			v2_scr_poe_on $1
	        ;;
		*)
			prn_usage
	        ;;
		esac
	fi
}


if [[ "$board_version" = "V2R"[0-9] ]]; then
	v2_scr_poe $1 $2
else
	v1_scr_poe $1 $2
fi

exit 0
