#!/bin/sh

# load hardware info (for usb_eth)
hwinfo_file=/tmp/hwinfo
. $hwinfo_file


# saved user config
default_file="/etc/setup-netcfg/default/default_user.cfg"
cfg_file="/etc/setup-netcfg/user.cfg"
cfg_temp="/www/pages/user.cfg.temp"
cfg_saved="/www/pages/user.cfg"

. $default_file
if [ -e $cfg_temp ]; then
	. $cfg_temp
elif [ -e $cfg_saved ]; then
	. $cfg_saved
else
	. $cfg_file
fi


# get lan client info ( > 5sec )
clist_file="/var/tmp/.clist"
./get_status.sh

# cam for poe ( > 1sec )
cam_info="/var/tmp/cam_info"
/usr/local/bin/discover-cam.sh > $cam_info
. $cam_info


# mac -> ip address
while read line
do
	tmp_mac=`echo $line | awk '{print $2}'`
	tmp_ip=`echo $line | awk '{print $1}'`
	if [ "$tmp_mac" = "$cam1_mac" ]; then
		cam1_ip=$tmp_ip
	fi
	if [ "$tmp_mac" = "$cam2_mac" ]; then
		cam2_ip=$tmp_ip
	fi
	if [ "$tmp_mac" = "$cam3_mac" ]; then
		cam3_ip=$tmp_ip
	fi
	if [ "$tmp_mac" = "$cam4_mac" ]; then
		cam4_ip=$tmp_ip
	fi
done < $clist_file


# camera info
cam_info_1="カメラ情報なし"
cam_info_2="カメラ情報なし"
cam_info_3="カメラ情報なし"
cam_info_4="カメラ情報なし"

cam1_idx=0
cam2_idx=0
cam3_idx=0
cam4_idx=0

for n in `seq 1 4`; do
	tmp="cam_mac_""$n"
	if [ -n "$cam1_mac" ] && [ "$cam1_mac" = "${!tmp}" ]; then
		cam1_idx=$n
	fi
	if [ -n "$cam2_mac" ] && [ "$cam2_mac" = "${!tmp}" ]; then
		cam2_idx=$n
	fi
	if [ -n "$cam3_mac" ] && [ "$cam3_mac" = "${!tmp}" ]; then
		cam3_idx=$n
	fi
	if [ -n "$cam4_mac" ] && [ "$cam4_mac" = "${!tmp}" ]; then
		cam4_idx=$n
	fi
done

for n in `seq 1 4`; do
	idx="cam""$n""_idx"
	p_name="product_name_""${!idx}"
	m_name="cam_modelName_""${!idx}"
	if [ -n "${!p_name}" ]; then
		tmp=${!p_name}
	else
		tmp=${!m_name}
	fi
	if [ -n "$tmp" ]; then
		case "$n" in
		1)
			cam_info_1="$tmp : $cam_sn_1"
		;;
		2)
			cam_info_2="$tmp : $cam_sn_2"
		;;
		3)
			cam_info_3="$tmp : $cam_sn_3"
		;;
		4)
			cam_info_4="$tmp : $cam_sn_4"
		;;
		esac
	fi
done


# poe interface
poe0_mac=""
poe1_mac=""

if [ "$cam_if_1" = "0" ]; then
	poe0_mac=$cam_mac_1
elif [ "$cam_if_2" = "0" ]; then
	poe0_mac=$cam_mac_2
elif [ "$cam_if_3" = "0" ]; then
	poe0_mac=$cam_mac_3
elif [ "$cam_if_4" = "0" ]; then
	poe0_mac=$cam_mac_4
else
	poe0_mac=""
fi

if [ "$cam_if_1" = "1" ]; then
	poe1_mac=$cam_mac_1
elif [ "$cam_if_2" = "1" ]; then
	poe1_mac=$cam_mac_2
elif [ "$cam_if_3" = "1" ]; then
	poe1_mac=$cam_mac_3
elif [ "$cam_if_4" = "1" ]; then
	poe1_mac=$cam_mac_4
else
	poe1_mac=""
fi


# info params
echo "["
echo "{ \"id\":\"usb_eth\", \"value\":\"$usb_eth\" },"
echo "{ \"id\":\"poe0_mac\", \"value\":\"$poe0_mac\" },"
echo "{ \"id\":\"poe1_mac\", \"value\":\"$poe1_mac\" },"
echo "{ \"id\":\"cam1_ip\", \"value\":\"$cam1_ip\" },"
echo "{ \"id\":\"cam2_ip\", \"value\":\"$cam2_ip\" },"
echo "{ \"id\":\"cam3_ip\", \"value\":\"$cam3_ip\" },"
echo "{ \"id\":\"cam4_ip\", \"value\":\"$cam4_ip\" },"
echo "{ \"id\":\"cam_info_1\", \"value\":\"$cam_info_1\" },"
echo "{ \"id\":\"cam_info_2\", \"value\":\"$cam_info_2\" },"
echo "{ \"id\":\"cam_info_3\", \"value\":\"$cam_info_3\" },"
echo "{ \"id\":\"cam_info_4\", \"value\":\"$cam_info_4\" }"
echo "]"
