#!/bin/sh

install_dir="/etc/openvpn"


infile=$1
if [ ! -e $infile ]; then
	exit 1
fi


work_dir="/var/tmp/ovpn"
if [ ! -e $work_dir ]; then
	mkdir -p $work_dir
fi

# base name of input file
conf_name=`basename $infile`
conf_name=${conf_name%.*}


# extract conf file. strip ca, cert, key
awk '{if($1 == "<ca>" || $1 == "<cert>" || $1 == "<key>") exit; else print $0}' $infile | \
awk '{if($1 != "ca" && $1 != "cert" && $1 != "key") print $0}' \
> $work_dir/${conf_name}.conf

echo "ca   $conf_name/ca.crt"          >> $work_dir/${conf_name}.conf
echo "cert $conf_name/$conf_name.crt"  >> $work_dir/${conf_name}.conf
echo "key  $conf_name/$conf_name.key"  >> $work_dir/${conf_name}.conf


# client directory
mkdir $work_dir/$conf_name

# extract ca file
awk 'BEGIN{flg=0}{if($1 == "<ca>") ++flg; if(flg == 1 && $0 ~ /BEGIN CERTIFICATE/) ++flg; if($1 == "</ca>") flg=0; if(flg > 1) print $0;}' $infile > $work_dir/$conf_name/ca.crt

# extract cert file
awk 'BEGIN{flg=0}{if($1 == "<cert>") ++flg; if(flg == 1 && $0 ~ /BEGIN CERTIFICATE/) ++flg; if($1 == "</cert>") flg=0; if(flg > 1) print $0;}' $infile > $work_dir/$conf_name/$conf_name.crt

# extract key file
awk 'BEGIN{flg=0}{if($1 == "<key>") ++flg; if(flg == 1 && $0 ~ /BEGIN /) ++flg; if($1 == "</key>") flg=0; if(flg > 1) print $0;}' $infile > $work_dir/$conf_name/$conf_name.key


if [ ! -e $work_dir/${conf_name}.conf ] || [ ! -e $work_dir/$conf_name/ca.crt ] || \
   [ ! -e $work_dir/$conf_name/$conf_name.crt ] || [ ! -e $work_dir/$conf_name/$conf_name.key ]; then
	rm -rf $work_dir
	exit 1
fi

if [ ! -s $work_dir/${conf_name}.conf ] || [ ! -s $work_dir/$conf_name/ca.crt ] || \
   [ ! -s $work_dir/$conf_name/$conf_name.crt ] || [ ! -s $work_dir/$conf_name/$conf_name.key ]; then
	exit 1
fi


# install and clean-up
sudo /bin/cp    $work_dir/$conf_name.conf $install_dir/
sudo /bin/cp -r $work_dir/$conf_name      $install_dir/

rm -rf $work_dir
sync

exit 0
